You can add new methods that should have a defined ```timeout`` argument as qualified names
in the ``timeout-methods`` option, for example:

* ``requests.api.get``
* ``requests.api.head``
* ``requests.api.options``
* ``requests.api.patch``
* ``requests.api.post``
* ``requests.api.put``
* ``requests.api.request``
